@@ -8,6 +8,6 @@
 #' @seealso \url{https://deck.gl/#/documentation/deckgl-api-reference/layers/great-circle-layer}
 #' @example inst/examples/deckgl-api-reference/great-circle-layer.R
 #' @export
-add_great_circle_layer <- function(deckgl, id = "great-circle-layer", data = NULL, properties = list(), ...) {
-  add_layer(deckgl, "GreatCircleLayer", id, data, properties, ...)
+add_great_circle_layer <- function(deckgl, data = NULL, properties = list(), ..., id = "great-circle-layer") {
+  add_layer(deckgl, "GreatCircleLayer", data, properties, ..., id = id)
 }
