@@ -7,6 +7,6 @@
 #' @seealso \url{https://deck.gl/#/documentation/deckgl-api-reference/layers/hexagon-layer}
 #' @example inst/examples/deckgl-api-reference/hexagon-layer.R
 #' @export
-add_hexagon_layer <- function(deckgl, id = "hexagon-layer", data = NULL, properties = list(), ...) {
-  add_layer(deckgl, "HexagonLayer", id, data, properties, ...)
+add_hexagon_layer <- function(deckgl, data = NULL, properties = list(), ..., id = "hexagon-layer") {
+  add_layer(deckgl, "HexagonLayer", data, properties, ..., id = id)
 }
