@@ -4,12 +4,9 @@
 #' and renders them as circles with a certain radius.
 #'
 #' @inheritParams add_layer
-#'
 #' @seealso \url{https://deck.gl/#/documentation/deckgl-api-reference/layers/scatterplot-layer}
-#'
 #' @example inst/examples/deckgl-api-reference/scatterplot-layer.R
-#'
 #' @export
-add_scatterplot_layer <- function(deckgl, id = "scatterplot-layer", data = NULL, properties = list(), ...) {
-  add_layer(deckgl, "ScatterplotLayer", id, data, properties, ...)
+add_scatterplot_layer <- function(deckgl, data = NULL, properties = list(), ..., id = "scatterplot-layer") {
+  add_layer(deckgl, "ScatterplotLayer", data, properties, ..., id = id)
 }
