@@ -4,12 +4,9 @@
 #' aggregates them into histogram bins and renders as a grid.
 #'
 #' @inheritParams add_layer
-#'
 #' @seealso \url{https://deck.gl/#/documentation/deckgl-api-reference/layers/screen-grid-layer}
-#'
 #' @example inst/examples/deckgl-api-reference/screen-grid-layer.R
-#'
 #' @export
-add_screen_grid_layer <- function(deckgl, id = "screen-grid-layer", data = NULL, properties = list(), ...) {
-  add_layer(deckgl, "ScreenGridLayer", id, data, properties, ...)
+add_screen_grid_layer <- function(deckgl, data = NULL, properties = list(), ..., id = "screen-grid-layer") {
+  add_layer(deckgl, "ScreenGridLayer", data, properties, ..., id = id)
 }
